@@ -17,21 +17,13 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/AspectRatio.h>
-#include <Lum/Button.h>
-#include <Lum/ButtonRow.h>
-#include <Lum/Dialog.h>
-#include <Lum/DirNameSelect.h>
-#include <Lum/Label.h>
-#include <Lum/LED.h>
-#include <Lum/Panel.h>
-#include <Lum/String.h>
-#include <Lum/Text.h>
-
 #include <Lum/Base/DateTime.h>
+#include <Lum/Base/L10N.h>
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/ActionDialog.h>
 #include <Lum/Dlg/Msg.h>
@@ -42,6 +34,17 @@
 
 #include <Lum/OS/Probe.h>
 
+#include <Lum/AspectRatio.h>
+#include <Lum/Button.h>
+#include <Lum/ButtonRow.h>
+#include <Lum/Dialog.h>
+#include <Lum/DirNameSelect.h>
+#include <Lum/Label.h>
+#include <Lum/LED.h>
+#include <Lum/Panel.h>
+#include <Lum/String.h>
+#include <Lum/Text.h>
+
 #include "config.h"
 #include "Configuration.h"
 #include "Control.h"
@@ -241,16 +244,27 @@ public:
     vpanel->Add(hpanel);
     vpanel->AddSpace();
     vpanel->Add(Lum::HPanel::Create(true,false)
-                ->Add(Lum::Button::Create(L"_Prefs...",settings))
-                ->AddSpace()
-                ->Add(Lum::Button::Create(L"_About...",about))
-                ->AddSpace()
                 ->Add(new Lum::Text(L"Prefix:"))
                 ->AddSpace()
                 ->Add(Lum::String::Create(imagePrefix,true,false)));
 
     SetMain(vpanel);
 
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
+
+    menu
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->GroupEdit()
+        ->ActionSettings(settings)
+      ->End()
+      ->GroupHelp()
+        //->ActionHelp()
+        ->ActionAbout(about);
+
+    SetMenu(menu);
+
     Dialog::PreInit();
   }
 
